==> types_boto3_full-1.35.90.tar.gz: types_boto3_full-1.35.90/types_boto3_marketplace_entitlement/type_defs.py <==
"""
Type annotations for marketplace-entitlement service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_marketplace_entitlement/type_defs/)

Usage::

    ```python
    from types_boto3_marketplace_entitlement.type_defs import EntitlementValueTypeDef

    data: EntitlementValueTypeDef = ...
    ```

Copyright 2024 Vlad Emelianov
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Mapping, Sequence

from .literals import GetEntitlementFilterNameType

if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict


__all__ = (
    "EntitlementTypeDef",
    "EntitlementValueTypeDef",
    "GetEntitlementsRequestPaginateTypeDef",
    "GetEntitlementsRequestRequestTypeDef",
    "GetEntitlementsResultTypeDef",
    "PaginatorConfigTypeDef",
    "ResponseMetadataTypeDef",
)


class EntitlementValueTypeDef(TypedDict):
    IntegerValue: NotRequired[int]
    DoubleValue: NotRequired[float]
    BooleanValue: NotRequired[bool]
    StringValue: NotRequired[str]


class PaginatorConfigTypeDef(TypedDict):
    MaxItems: NotRequired[int]
    PageSize: NotRequired[int]
    StartingToken: NotRequired[str]


class GetEntitlementsRequestRequestTypeDef(TypedDict):
    ProductCode: str
    Filter: NotRequired[Mapping[GetEntitlementFilterNameType, Sequence[str]]]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class EntitlementTypeDef(TypedDict):
    ProductCode: NotRequired[str]
    Dimension: NotRequired[str]
    CustomerIdentifier: NotRequired[str]
    Value: NotRequired[EntitlementValueTypeDef]
    ExpirationDate: NotRequired[datetime]


class GetEntitlementsRequestPaginateTypeDef(TypedDict):
    ProductCode: str
    Filter: NotRequired[Mapping[GetEntitlementFilterNameType, Sequence[str]]]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class GetEntitlementsResultTypeDef(TypedDict):
    Entitlements: list[EntitlementTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]

==> types_boto3_full-1.36.4.tar.gz: types_boto3_full-1.36.4/types_boto3_marketplace_entitlement/type_defs.py <==
"""
Type annotations for marketplace-entitlement service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_marketplace_entitlement/type_defs/)

Usage::

    ```python
    from types_boto3_marketplace_entitlement.type_defs import EntitlementValueTypeDef

    data: EntitlementValueTypeDef = ...
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from datetime import datetime

from .literals import GetEntitlementFilterNameType

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import list as List
    from collections.abc import Mapping, Sequence
else:
    from typing import Dict, List, Mapping, Sequence
if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict


__all__ = (
    "EntitlementTypeDef",
    "EntitlementValueTypeDef",
    "GetEntitlementsRequestPaginateTypeDef",
    "GetEntitlementsRequestRequestTypeDef",
    "GetEntitlementsResultTypeDef",
    "PaginatorConfigTypeDef",
    "ResponseMetadataTypeDef",
)


class EntitlementValueTypeDef(TypedDict):
    IntegerValue: NotRequired[int]
    DoubleValue: NotRequired[float]
    BooleanValue: NotRequired[bool]
    StringValue: NotRequired[str]


class PaginatorConfigTypeDef(TypedDict):
    MaxItems: NotRequired[int]
    PageSize: NotRequired[int]
    StartingToken: NotRequired[str]


class GetEntitlementsRequestRequestTypeDef(TypedDict):
    ProductCode: str
    Filter: NotRequired[Mapping[GetEntitlementFilterNameType, Sequence[str]]]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: Dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class EntitlementTypeDef(TypedDict):
    ProductCode: NotRequired[str]
    Dimension: NotRequired[str]
    CustomerIdentifier: NotRequired[str]
    Value: NotRequired[EntitlementValueTypeDef]
    ExpirationDate: NotRequired[datetime]


class GetEntitlementsRequestPaginateTypeDef(TypedDict):
    ProductCode: str
    Filter: NotRequired[Mapping[GetEntitlementFilterNameType, Sequence[str]]]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class GetEntitlementsResultTypeDef(TypedDict):
    Entitlements: List[EntitlementTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]
